@@ -529,7 +529,7 @@ class sqlite(Base):
 	def recent(self, table: str, order_by_field: str):
 		with self.connection:
 			sql = (f"SELECT * FROM `{table}` ORDER BY `{order_by_field}` DESC LIMIT 1")
-			return self.cursor.execute(sql).fetchall()
+			return self.cursor.execute(sql).fetchone()
 			
 	def read(self, table: str, fields: tuple, sub_sql: str=None, *values):
 		fields = "`" + "`, `".join(fields) + "`"
